// Mongoose DB Configuration and init
'use strict';

const cluster = require('cluster');
const chalk = require('chalk');
const config = require('./config')();
const glob = require('glob');
const winston = require('winston');

// Print Once
function _printOnce(){
  return cluster.isMaster || (cluster.worker && cluster.worker.id==1);
}

// Connect to DB
function connect(mongoose, options){
  if(mongoose.connection.readyState==1 || mongoose.connection.readyState==2){
    return;
  }

  var Server = config.get().db.server || 'localhost';
  var DBName = config.get().db.name || 'mio-demo';

  if(options && options.server && options.name){
    Server = options.server;
    DBName = options.name;
  }

  if(_printOnce()){
    winston.info('-'.repeat(70));
    winston.info('Using DataBase:', chalk.blue(Server,'/',DBName));
  }

  mongoose.connect('mongodb://'+Server+'/'+DBName, (err) => {
    if(err) {
      winston.error('Error with DataBase', DBName, ':', err);
      process.exit();
    }
  });

  if(!global.mio.mongo){
    global.mio.mongo = {
      mongoose: mongoose,
      connection: mongoose.connection
    };
  }
}

// Load static data models
function loadModels(){
  var files = glob.sync(global.mio.appPath+'/modules/*/models/*.js');
  var modulesNames = [];
  for (var i = 0; i < files.length; i++) {
    var moduleName = files[i].split('/')[1];
    try {
      require(files[i]);
      if(modulesNames.indexOf(moduleName) == -1) modulesNames.push(moduleName);
    } catch (err) {
      winston.error('Can\'t load models for ', moduleName);
      winston.error(err);
    }
  }
}

// Magic init
function init(mongoose, options){
  connect(mongoose, options);
  loadModels(mongoose);
}

module.exports = {
  init: init,
  connect: connect,
  loadModels: loadModels
};
