'use strict';

const extensionParser = require('mio-extensions');
const i18n = require('mio-i18n')({path: 'i18n', defaultLocale: 'en'});

// List materials
function error(req, res, err){
  var errorCode = 406;
  const genericMessage = i18n.get('errors.generic.message');
  const genericHint = i18n.get('errors.generic.hint');
  var errorMessage;

  if(err){
    if(typeof err == 'number'){
      errorCode = parseInt(err);
    }else if(err.code){
      errorCode = err.code;
    }

    if(typeof err == 'string'){
      errorMessage = err;
      if(err.toLowerCase() == 'not found' || err.toLowerCase() == 'not found!'){
        errorCode = 404;
      }
    }else if (err.message){
      errorMessage = err.message;
      if(errorMessage.split(' ')[0]=='E11000'){
        errorMessage = 'Already Exist!';
      }
    }else{
      errorMessage = i18n.get('errors.'+errorCode+'.message', genericMessage);
    }

  }

  const errorHint = i18n.get('errors.'+errorCode+'.hint', genericHint);
  const ps = i18n.get('messages.nothingHere', 'Actually, there is nothing to see here...');
  const error = i18n.get('errors.error', 'Error');

  extensionParser.render(req, res, {
    status: errorCode,
    template: 'views/error.vash',
    data: {
      code: errorCode,
      message: errorMessage,
      hint: errorHint,
      ps: ps,
      error: error
    }
  });
}

// Export methods
module.exports = {
  error: error
};
